@@ -33,7 +33,7 @@ class BaseService(models.Model):
     A base service class intended to be subclassed.
     """
     name = models.CharField(max_length=255)
-    hostname = models.CharField(max_length=255, unique=True)
+    hostname = models.CharField(max_length=255)
     PORT = 0  # Should be overriden by subclass
     connection = None
 
@@ -177,6 +177,9 @@ class APNService(BaseService):
     def __unicode__(self):
         return u'APNService %s' % self.name
 
+    class Meta:
+        unique_together = ('name', 'hostname')
+
 
 class Notification(models.Model):
     """
@@ -220,8 +223,6 @@ class Device(models.Model):
     """
     Represents an iOS device with unique token.
     """
-    PLATFORM_CHOICES = (('iPhone', 'iPhone'), ('iPad', 'iPad'), ('iPod', 'iPod'))
-
     token = models.CharField(max_length=64, blank=False, null=False)
     is_active = models.BooleanField(default=True)
     deactivated_at = models.DateTimeField(null=True, blank=True)
@@ -229,8 +230,9 @@ class Device(models.Model):
     users = models.ManyToManyField(User, null=True, blank=True, related_name='ios_devices')
     added_at = models.DateTimeField(auto_now_add=True)
     last_notified_at = models.DateTimeField(null=True, blank=True)
-    platform = models.CharField(max_length=30, blank=True, null=True, choices=PLATFORM_CHOICES)
+    platform = models.CharField(max_length=30, blank=True, null=True)
     display = models.CharField(max_length=30, blank=True, null=True)
+    os_version = models.CharField(max_length=20, blank=True, null=True)
 
     def push_notification(self, notification):
         """
@@ -292,3 +294,6 @@ class FeedbackService(BaseService):
 
     def __unicode__(self):
         return u'FeedbackService %s' % self.name
+
+    class Meta:
+        unique_together = ('name', 'hostname')
